import argparse
import os

from core import PacketSniffer
from output import OutputToScreen


parser = argparse.ArgumentParser(description="Network packet sniffer")
parser.add_argument(
    "-i", "--interface",
    type=str,
    default=None,
    help="Interface from which Ethernet frames will be captured (monitors "
         "all available interfaces by default)."
)
parser.add_argument(
    "-d", "--data",
    action="store_true",
    help="Output packet data during capture."
)
_args = parser.parse_args()

if os.getuid() != 0:
    raise SystemExit("Error: Permission denied. This application requires "
                     "administrator privileges to run.")

OutputToScreen(
    subject=(sniffer := PacketSniffer()),
    display_data=_args.data
)

try:
    for _ in sniffer.listen(_args.interface):
        '''Iterate through the frames yielded by the listener in an 
        infinite cycle while feeding them to all registered observers 
        for further processing/output'''
        pass
except KeyboardInterrupt:
    raise SystemExit("[!] Aborting packet capture...")



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['net_sniffer']

package_data = \
{'': ['*']}

install_requires = \
['netprotocols>=0.5.0,<0.6.0', 'pyinstaller>=5.1,<6.0']

setup_kwargs = {
    'name': 'net-sniffer',
    'version': '3.0.0',
    'description': 'A Network Packet Sniffing tool developed in Python 3',
    'long_description': None,
    'author': 'EONRaider',
    'author_email': 'livewire_voodoo@protonmail.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': None,
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.8,<3.11',
}


setup(**setup_kwargs)
